@@ -15,7 +15,11 @@ use XML::Twig ;
 use File::Share ':all'; 
 use Carp qw (cluck croak carp) ;
 
-use base qw( Metabolomics::Banks ) ;
+use Metabolomics::Banks qw( :all ) ;
+
+require Exporter;
+
+our @ISA = qw(Exporter);
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -46,12 +50,11 @@ Metabolomics::Banks::BloodExposome - Perl extension for BloodExposome bank
 
 =head1 VERSION
 
-Version 0.2 - Adding POD
-Version 0.3 - Completing object properties
+Version 0.1
 
 =cut
 
-our $VERSION = '0.3';
+our $VERSION = '0.1';
 
 
 =head1 SYNOPSIS
@@ -65,15 +68,9 @@ our $VERSION = '0.3';
 
 =head1 EXPORT
 
-use Metabolomics::Banks::BloodExposome qw( :all ) ;
+=head1 SUBROUTINES/METHODS
 
-=head1 PUBLIC METHODS 
-
-=head2 Metabolomics::Fragment::Annotation
-
-=over 4
-
-=item new 
+=head2 METHOD new
 
 	## Description : new
 	## Input : $self
@@ -84,34 +81,129 @@ use Metabolomics::Banks::BloodExposome qw( :all ) ;
 
 sub new {
     ## Variables
-    my ($class,$args) = @_;
     my $self={};
-        
+    bless($self) ;
+    
     $self = Metabolomics::Banks->new() ;
     
     $self->{_DATABASE_NAME_} = 'Blood Exposome' ;
     $self->{_DATABASE_VERSION_} = '1.0' ;
     $self->{_DATABASE_ENTRIES_NB_} = 'database_entries_nb' ;
-    $self->{_DATABASE_URL_} = 'http://bloodexposome.org/' ;
-    $self->{_DATABASE_URL_CARD_} = 'https://pubchem.ncbi.nlm.nih.gov/#query=' ; # BloodExposome is linked with pubchem CID
-    $self->{_DATABASE_TYPE_} = 'METABOLITE' ;
-    $self->{_POLARITY_} =  $args->{POLARITY} ;
+    $self->{_DATABASE_URL_} = 'database_url' ;
     $self->{_DATABASE_DOI_} = 'database_doi' ;
     ## _DATABASE_ENTRIES_
-    bless($self) ;
+    
     return $self ;
 }
 ### END of SUB
 
-=item getMetabolitesFromSource
+=head2 METHOD __refBloodExposomeEntry__
+
+	## Description : init a new blood exposome entry
+	## Input : void	
+	## Output : refEntry
+	## Usage : $self->__refBloodExposomeEntry__() ;
+	
+=cut
+## START of SUB
+sub __refBloodExposomeEntry__ {
+    ## Variables
+    my ($class,$args) = @_;
+    my $self={};
+
+    bless($self) ;
+    
+    $self->{_PUBCHEM_CID_} = 'pubchem_cid' ; # 
+    $self->{_COMPOUND_NAME_} = 'compound_name' ; # 
+	$self->{_KEGG_ID_} = 'kegg_id' ;
+	$self->{_HMDB_ID_} = 'hmdb_id' ;
+	$self->{_MOLECULAR_FORMULA_} = 'molecular_formula' ;
+	$self->{_CANONICAL_SMILES_} = 'canonical_smiles' ;
+	$self->{_INCHIKEY_} = 'inchikey' ;
+	$self->{_MULTI_COMPONENT_} = 'multi_component' ;
+	$self->{_XLOGP_} = 'xlogp' ;
+    $self->{_EXACT_MASS_} = 'exact_mass' ;
+    $self->{_CHARGE_} = 'charge' ;
+
+    return $self ;
+}
+### END of SUB
+
+=head2 METHOD _getEntry_EXACT_MASS
+
+	## Description : PRIVATE method _getEntry_EXACT_MASS on a refBloodExposomeEntry object
+	## Input : void
+	## Output : $EXACT_MASS
+	## Usage : my ( $EXACT_MASS ) = $entry->_getEntry_EXACT_MASS () ;
+	
+=cut
+## START of SUB
+sub _getEntry_EXACT_MASS {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $EXACT_MASS = undef ;
+    
+    if ( (defined $self->{_EXACT_MASS_}) and ( $self->{_EXACT_MASS_} > 0 ) or $self->{_EXACT_MASS_} < 0  ) {	$EXACT_MASS = $self->{_EXACT_MASS_} ; }
+    else {	 $EXACT_MASS = 0 ; warn "[WARN] the method _getEntry_EXACT_MASS can't _get a undef or non numerical value\n" ; }
+    
+    return ( $EXACT_MASS ) ;
+}
+### END of SUB
+
+=head2 METHOD _getEntry_CHARGE
+
+	## Description : PRIVATE method _getEntry_CHARGE on a refBloodExposomeEntry object
+	## Input : void
+	## Output : $CHARGE
+	## Usage : my ( $CHARGE ) = $entry->_getEntry_CHARGE () ;
+	
+=cut
+## START of SUB
+sub _getEntry_CHARGE {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $CHARGE = undef ;
+    
+    if ( (defined $self->{_CHARGE_}) and ( $self->{_CHARGE_} > 0  or $self->{_CHARGE_} < 0 or $self->{_CHARGE_} == 0 )   ) {	$CHARGE = $self->{_CHARGE_} ; }
+    else {	 $CHARGE = 0 ; warn "[WARN] the method _getEntry_CHARGE can't _get a undef or non numerical value\n" ; }
+    
+    return ( $CHARGE ) ;
+}
+### END of SUB
+
+=head2 METHOD _getEntry_COMPOUND_NAME
+
+	## Description : PRIVATE method _getEntry_COMPOUND_NAME on a refBloodExposomeEntry object
+	## Input : void
+	## Output : $COMPOUND_NAME
+	## Usage : my ( $COMPOUND_NAME ) = $entry->_getEntry_COMPOUND_NAME () ;
+	
+=cut
+## START of SUB
+sub _getEntry_COMPOUND_NAME {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $COMPOUND_NAME = undef ;
+    
+    if ( (defined $self->{_COMPOUND_NAME_}) and ( $self->{_COMPOUND_NAME_} ne '' ) ) {	$COMPOUND_NAME = $self->{_COMPOUND_NAME_} ; }
+    else {	 $COMPOUND_NAME = undef ; warn "[WARN] the method _getEntry_COMPOUND_NAME can't _get a undef or non numerical value\n" ; }
+    
+    return ( $COMPOUND_NAME ) ;
+}
+### END of SUB
+
+
+=head2 METHOD getMetabolitesFromSource
 
 	## Description : get the list of metabolite entries from $source file and set the Metabolomics::Banks::BloodExposome object
 	## Input : $source (file from the metabolomics-references project)
 	## Output : an int as $entriesNb
 	## Usage : my ( $entriesNb ) = $self->getMetabolitesFromSource ( $source ) ;
-
+	
 =cut
-
 ## START of SUB
 sub getMetabolitesFromSource {
     ## Retrieve Values
@@ -120,17 +212,6 @@ sub getMetabolitesFromSource {
     
     my $entriesNb = 0 ;
     
-    if (!defined $source) {
-
-    	$source = dist_file('Metabolomics-Fragment-Annotation', 'BloodExposome_v1_0.txt');
-    	if (-e $source) {
-    		print "loading $source...\n" ;
-    	}
-    	else {
-    		croak "The source file ($source) does not exist at this path\n" ;
-    	}
-    }
-    
     if ( (defined $source) and (-e $source) ) {
     	
     	my $oEntry = $self->__refBloodExposomeEntry__() ;
@@ -178,15 +259,15 @@ sub getMetabolitesFromSource {
 }
 ### END of SUB
 
-=item METHOD buildTheoPeakBankFromEntries
+
+=head2 METHOD buildTheoPeakBankFromEntries
 
 	## Description : building from a Metabolomics::Banks::BloodExposome object, a bank integrating each potential entry in a metabolomics format (POSITIVE or NEGATIVE forms)
 	## Input : $queryMode [POS|NEG]
 	## Output : int as $entryNb
 	## Usage : my $nb = $oBank->buildTheoPeakBankFromEntries() ;
-
+	
 =cut
-
 ## START of SUB
 sub buildTheoPeakBankFromEntries {
     ## Retrieve Values
@@ -196,7 +277,7 @@ sub buildTheoPeakBankFromEntries {
     my $mode = undef ;
 
     my $entries = $self->_getEntries();
-        
+    
     my $entryNb = 0 ; 
 
     foreach my $entry (@{$entries}) {
@@ -261,12 +342,7 @@ sub buildTheoPeakBankFromEntries {
     		$oPeak->_setPeak_COMPUTED_MONOISOTOPIC_MASS ( $computedMz );
     	}
     	
-    	## set all others properties
 	    $oPeak->_setPeak_ANNOTATION_NAME ( $entry->_getEntry_COMPOUND_NAME() );
-	    $oPeak->_setPeak_ANNOTATION_FORMULA ( $entry->_getEntry_MOLECULAR_FORMULA() );
-	    $oPeak->_setPeak_ANNOTATION_SMILES ( $entry->_getEntry_CANONICAL_SMILES() );
-	    $oPeak->_setPeak_ANNOTATION_INCHIKEY ( $entry->_getEntry_INCHIKEY() );
-	    $oPeak->_setPeak_ANNOTATION_ID ( 'CID'.$entry->_getEntry_PUBCHEM_CID() );
 	    
 	    $self->_addPeakList('_THEO_PEAK_LIST_', $oPeak) ;
 	    
@@ -280,213 +356,12 @@ sub buildTheoPeakBankFromEntries {
 }
 ### END of SUB
 
-=back
 
-=head1 PRIVATE METHODS
 
-=head2 Metabolomics::Banks::BloodExposome
-
-=over 4
-
-=item PRIVATE_ONLY __refBloodExposomeEntry__
-
-	## Description : init a new blood exposome entry
-	## Input : void	
-	## Output : refEntry
-	## Usage : $self->__refBloodExposomeEntry__() ;
-
-=cut
-
-## START of SUB
-sub __refBloodExposomeEntry__ {
-    ## Variables
-    my ($class,$args) = @_;
-    my $self={};
-
-    bless($self) ;
-    
-    $self->{_PUBCHEM_CID_} = 'pubchem_cid' ; # 
-    $self->{_COMPOUND_NAME_} = 'compound_name' ; # 
-	$self->{_KEGG_ID_} = 'kegg_id' ;
-	$self->{_HMDB_ID_} = 'hmdb_id' ;
-	$self->{_MOLECULAR_FORMULA_} = 'molecular_formula' ;
-	$self->{_CANONICAL_SMILES_} = 'canonical_smiles' ;
-	$self->{_INCHIKEY_} = 'inchikey' ;
-	$self->{_MULTI_COMPONENT_} = 'multi_component' ;
-	$self->{_XLOGP_} = 'xlogp' ;
-    $self->{_EXACT_MASS_} = 'exact_mass' ;
-    $self->{_CHARGE_} = 'charge' ;
-
-    return $self ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getEntry_EXACT_MASS
-
-	## Description : PRIVATE method _getEntry_EXACT_MASS on a refBloodExposomeEntry object
-	## Input : void
-	## Output : $VALUE
-	## Usage : my ( $VALUE ) = $entry->_getEntry_EXACT_MASS () ;
-
-=cut
-
-## START of SUB
-sub _getEntry_EXACT_MASS {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $VALUE = undef ;
-    
-    if ( (defined $self->{_EXACT_MASS_}) and ( $self->{_EXACT_MASS_} > 0 ) or $self->{_EXACT_MASS_} < 0  ) {	$VALUE = $self->{_EXACT_MASS_} ; }
-    else {	 $VALUE = 0 ; warn "[WARN] the method _getEntry_EXACT_MASS get a undef value\n" ; }
-    
-    return ( $VALUE ) ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getEntry_CHARGE
-
-	## Description : PRIVATE method _getEntry_CHARGE on a refBloodExposomeEntry object
-	## Input : void
-	## Output : $VALUE
-	## Usage : my ( $VALUE ) = $entry->_getEntry_CHARGE () ;
-
-=cut
-
-## START of SUB
-sub _getEntry_CHARGE {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $VALUE = undef ;
-    
-    if ( (defined $self->{_CHARGE_}) and ( $self->{_CHARGE_} > 0  or $self->{_CHARGE_} < 0 or $self->{_CHARGE_} == 0 )   ) {	$VALUE = $self->{_CHARGE_} ; }
-    else {	 $VALUE = 0 ; warn "[WARN] the method _getEntry_CHARGE get an undef value\n" ; }
-    
-    return ( $VALUE ) ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getEntry_COMPOUND_NAME
-
-	## Description : PRIVATE method _getEntry_COMPOUND_NAME on a refBloodExposomeEntry object
-	## Input : void
-	## Output : $COMPOUND_NAME
-	## Usage : my ( $COMPOUND_NAME ) = $entry->_getEntry_COMPOUND_NAME () ;
-
-=cut
-
-## START of SUB
-sub _getEntry_COMPOUND_NAME {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $VALUE = undef ;
-    
-    if ( (defined $self->{_COMPOUND_NAME_}) and ( $self->{_COMPOUND_NAME_} ne '' ) ) {	$VALUE = $self->{_COMPOUND_NAME_} ; }
-    else {	 $VALUE = undef ; warn "[WARN] the method _getEntry_COMPOUND_NAME get an undef value\n" ; }
-    
-    return ( $VALUE ) ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getEntry_MOLECULAR_FORMULA
-
-	## Description : PRIVATE method _getEntry_MOLECULAR_FORMULA on a refBloodExposomeEntry object
-	## Input : void
-	## Output : $VALUE
-	## Usage : my ( $VALUE ) = $entry->_getEntry_MOLECULAR_FORMULA () ;
-
-=cut
-
-## START of SUB
-sub _getEntry_MOLECULAR_FORMULA {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $VALUE = undef ;
-    
-    if ( (defined $self->{_MOLECULAR_FORMULA_}) and ( $self->{_MOLECULAR_FORMULA_} ne '' ) ) {	$VALUE = $self->{_MOLECULAR_FORMULA_} ; }
-    else {	 $VALUE = undef ; warn "[WARN] the method _getEntry_MOLECULAR_FORMULA get an undef value\n" ; }
-    
-    return ( $VALUE ) ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getEntry_CANONICAL_SMILES
-
-	## Description : PRIVATE method _getEntry_CANONICAL_SMILES on a refBloodExposomeEntry object
-	## Input : void
-	## Output : $VALUE
-	## Usage : my ( $VALUE ) = $entry->_getEntry_CANONICAL_SMILES () ;
-
-=cut
-
-## START of SUB
-sub _getEntry_CANONICAL_SMILES {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $VALUE = undef ;
-    
-    if ( (defined $self->{_CANONICAL_SMILES_}) and ( $self->{_CANONICAL_SMILES_} ne '' ) ) {	$VALUE = $self->{_CANONICAL_SMILES_} ; }
-    else {	 $VALUE = undef ; warn "[WARN] the method _getEntry_CANONICAL_SMILES get an undef value\n" ; }
-    
-    return ( $VALUE ) ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getEntry_INCHIKEY
-
-	## Description : PRIVATE method _getEntry_INCHIKEY on a refBloodExposomeEntry object
-	## Input : void
-	## Output : $VALUE
-	## Usage : my ( $VALUE ) = $entry->_getEntry_INCHIKEY () ;
-
-=cut
-
-## START of SUB
-sub _getEntry_INCHIKEY {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $VALUE = undef ;
-    
-    if ( (defined $self->{_INCHIKEY_}) and ( $self->{_INCHIKEY_} ne '' ) ) {	$VALUE = $self->{_INCHIKEY_} ; }
-    else {	 $VALUE = undef ; warn "[WARN] the method _getEntry_INCHIKEY get an undef value\n" ; }
-    
-    return ( $VALUE ) ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getEntry_PUBCHEM_CID
-
-	## Description : PRIVATE method _getEntry_PUBCHEM_CID on a refBloodExposomeEntry object
-	## Input : void
-	## Output : $VALUE
-	## Usage : my ( $VALUE ) = $entry->_getEntry_PUBCHEM_CID () ;
-
-=cut
-
-## START of SUB
-sub _getEntry_PUBCHEM_CID {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $VALUE = undef ;
-    
-    if ( (defined $self->{_PUBCHEM_CID_}) and ( $self->{_PUBCHEM_CID_} ne '' ) ) {	$VALUE = $self->{_PUBCHEM_CID_} ; }
-    else {	 $VALUE = undef ; warn "[WARN] the method _getEntry_PUBCHEM_CID get an undef value\n" ; }
-    
-    return ( $VALUE ) ;
-}
-### END of SUB
 
 
 __END__
 
-=back
-
 =head1 AUTHOR
 
 Franck Giacomoni, C<< <franck.giacomoni at inra.fr> >>
@@ -531,7 +406,6 @@ L<https://metacpan.org/release/Metabolomics-Fragment-Annotation>
 
 =head1 ACKNOWLEDGEMENTS
 
-Thank you to INRAE and All metabolomics colleagues.
 
 =head1 LICENSE AND COPYRIGHT
 
